@@ -257,83 +257,10 @@ bool Bayonne::loadMonitor(const char *path)
         return true;                
 }
 
-#ifdef	HAVE_CAPAUDIO
-bool Bayonne::loadAudio(const char *path)
-{
-        char pathbuf[256];
-        const char *cp, *kv;
-	const char *prefix = NULL;
-        DSO *dso;
-
-#ifdef	WIN32
-#ifdef	HAVE_TESTING
-        if(!prefix && provision_test)
-#ifdef  NDEBUG
-                prefix = "DEBUG";
-#else
-                prefix = "RELEASE";
-#endif 
-#endif
-	if(!prefix)
-		"C:\\Program Files\\Common Files\\GNU Telephony\\Bayonne Audio";
-#else
-        char prefixbuf[256];
-
-#ifdef	HAVE_TESTING
-        if(!prefix && provision_test && !strchr(path, '/'))
-        {
-                snprintf(prefixbuf, sizeof(prefixbuf),
-                        "%s/modules/%s/.libs", SOURCE_FILES, path);
-                if(!isDir(prefixbuf))  
-                        snprintf(prefixbuf, sizeof(prefixbuf),
-                                "%s/modules/%s", SOURCE_FILES, path);
-                prefix = prefixbuf;
-        } 
-#endif
-	if(!prefix)
-		prefix = LIBDIR_FILES;
-#endif
-
-#ifdef  WIN32
-        snprintf(pathbuf, sizeof(pathbuf), "%s/%s." RLL_SUFFIX, prefix, path);
-#else
-        snprintf(pathbuf, sizeof(pathbuf), "%s/%s.cap", prefix, path);
-#endif  
-        cp = path;
-        path = pathbuf;
-
-        kv = server->getLast(path);
-        if(kv)
-        {
-                if(!stricmp(kv, "loaded"))
-                        return true;
-		return false;
-	}
-
-        if(!canAccess(path))
-        {
-                errlog("access", "cannot load %s", path);
-                return false;
-        }
-
-        dso = new DSO(path);
-        if(!dso->isValid())
-        {
-                kv = dso->getError();
-                server->setValue(path, kv);
-                errlog("error", "cannot initialize %s", path);
-                return false;
-        }
-        server->setValue(path, "loaded");
-        return true;                
-}
-
-#else
 bool Bayonne::loadAudio(const char *cp)
 {
 	return false;
 }
-#endif
 
 Bayonne::Handler Bayonne::getState(const char *id)
 {
