@@ -81,6 +81,7 @@ BayonneDriver::~BayonneDriver()
 void BayonneDriver::del(BayonneSession *session)
 {
 	BayonneDriver *driver = session->driver;
+	BayonneSpan *span = session->span;
 
 	if(!session->isAvail)
 		return;
@@ -97,12 +98,15 @@ void BayonneDriver::del(BayonneSession *session)
 	session->isAvail = false;
 	--driver->avail;
 	--idle_count;
+	if(span)
+		++span->used;
 	driver->leave();
 }
 
 void BayonneDriver::add(BayonneSession *session)
 {
 	BayonneDriver *driver = session->driver;
+	BayonneSpan *span = session->span;
 
 	if(session->isAvail)
 		return;
@@ -120,6 +124,8 @@ void BayonneDriver::add(BayonneSession *session)
 	}
 	++driver->avail;
 	session->isAvail = true;
+	if(span && span->used > 0)
+		--span->used;
 	driver->leave();
 	if(++idle_count > idle_limit)
 		idle_limit = idle_count;
@@ -132,6 +138,27 @@ void BayonneDriver::add(BayonneSession *session)
 	}		
 }
 
+bool BayonneDriver::isSpanable(unsigned spid)
+{
+	BayonneSpan *span = getSpan(spid);
+
+	if(!span)
+		return false;
+
+	if(span->driver != this)
+		return false;
+
+	if(span->used >= span->count)
+		return false;
+
+	return true;
+}
+
+bool BayonneDriver::getDestination(const char *server, const char *user, char *buf, size_t size)
+{
+	return false;
+}
+
 BayonneDriver *BayonneDriver::loadProtocol(const char *id, unsigned timeslots)
 {
 	char buf[65];
