@@ -275,6 +275,15 @@ public:
 	result_t addSym(const char *id, const char *value);
 	result_t setSym(const char *id, const char *value);
 	result_t getSym(const char *id, char *buf, unsigned size);
+
+        /**
+         * Post a symbol asychrononous event to server.  This sets the
+         * symbol value, and also generates a @posted:symname event.
+         *
+         * @param id of symbol to post.
+         * @param value of symbol.
+         */  
+	void postSym(const char *id, const char *value);
 };	 
 
 class __EXPORT BayonneTSession : public BayonneSession
@@ -282,6 +291,7 @@ class __EXPORT BayonneTSession : public BayonneSession
 protected:
 	friend class __EXPORT BayonneSysexec;
 
+	void sysPost(const char *sid, char *id, const char *value);
         void sysVar(const char *tsid, char *id, const char *value, int size);
         void sysHeader(const char *tsid);
         void sysArgs(const char *tsid);
