@@ -104,11 +104,6 @@ void BayonneSession::initialize(void)
 	setSid();
 }
 
-bool BayonneSession::setFeeder(BayonneFeeder *feeder)
-{
-	return false;
-}
-
 void BayonneSession::detach(void)
 {
 	exittimer = 0;
@@ -1026,7 +1021,7 @@ void BayonneSession::check(void)
 		return;
 	}
 
-	if(line->mask & 0x8 || server->isInput(line))
+	if((frame[stack].mask & 0x8) || server->isInput(line))
 	{
 		dtmf = enableDTMF();
 		return;
