@@ -19,12 +19,7 @@
 #include <cc++/process.h>
 #include <ccrtp/rtp.h>
 #undef	HAVE_CONFIG_H
-#ifdef	HAVE_EXOSIP2
-#include <osip2/osip_mt.h> 
-#include <eXosip2/eXosip.h>
-#else
 #include <eXosip/eXosip.h>
-#endif
 
 namespace sipdriver {
 using namespace ost;
