@@ -48,7 +48,7 @@ public:
 #endif
 
 RPCServer::RPCServer() :
-BayonneService(-1, 0), Keydata(KEYS)
+BayonneService(-1, 0), Keydata(Bayonne::getKeypath(KEYS))
 {
 	static Keydata::Define defkeys[] = {
 	{"protocols", "tcp udp"},
