@@ -22,23 +22,6 @@ namespace server {
 using namespace ost;
 using namespace std;
 
-const char *Checks::chkBGM(Line *line, ScriptImage *img)
-{
-	if(getMember(line))
-		return "bgm has no members";
-
-	if(hasKeywords(line))
-		return "bgm uses no keywords";
-
-	if(line->argc > 1)
-		return "bgm has only one argument";
-
-	if(!line->argc)
-		return "bgm feed argument is missing";
-
-	return NULL;
-}
-
 const char *Checks::chkConfig(Line *line, ScriptImage *img)
 {
 	Name *scr = img->getCurrent();
@@ -621,7 +604,7 @@ const char *Checks::chkCollect(Line *line, ScriptImage *img)
 	unsigned idx = 0;
 	const char *cp;
 
-	if(!useKeywords(line, "=count=timeout=interdigit=ignore=exit=format"))
+	if(!useKeywords(line, "=count=timeout=lastdigit=interdigit=ignore=exit=format"))
 		return "invalid keyword for collect";
 
 	cp = getOption(line, &idx);
@@ -640,7 +623,7 @@ const char *Checks::chkInput(Line *line, ScriptImage *img)
 	if(getMember(line))
 		return "input has no members";
 
-	if(!useKeywords(line, "=count=timeout=interdigit=exit=format"))
+	if(!useKeywords(line, "=count=timeout=interdigit=lastdigit=exit=format"))
 		return "invalid keyword for input, use timeout, interdigit, count, format, and exit";
 
 	cp = getOption(line, &idx);	
