@@ -27,8 +27,6 @@ Runtime::Runtime() :
 ScriptRuntime()
 {
 	static ScriptInterp::Define interp[] = {
-		{"bgm", false, (Method)&Methods::scrBGM,
-			(Check)&Checks::chkBGM},
 		{"config", true, (Method)&ScriptMethods::scrNop,
 			(Check)&Checks::chkConfig},
 		{"dialtone", false, (Method)&Methods::scrTone,
@@ -121,10 +119,6 @@ ScriptRuntime()
 			(Check)&Checks::chkCleardigits},
 		{"replay", false, (Method)&Methods::scrReplay,
 			(Check)&Checks::chkReplay},
-		{"endmenu", false, (Method)&Methods::scrEndmenu,
-			(Check)&Checks::chkCleardigits},
-		{"menudef", false, (Method)&Methods::scrMenu,
-			(Check)&Checks::chkCleardigits},
 		{"prompt", false, (Method)&Methods::scrPrompt,
 			(Check)&Checks::chkPathname},
 		{"speak", false, (Method)&Methods::scrPrompt,
@@ -172,7 +166,6 @@ ScriptRuntime()
 
 	load(interp);
 
-	ScriptInterp::addConditional("number", &testNumber);
 	ScriptInterp::addConditional("file", &testFile);
 	ScriptInterp::addConditional("dir", &testDir);
 	ScriptInterp::addConditional("span", &testSpan);
@@ -181,8 +174,6 @@ ScriptRuntime()
 	ScriptInterp::addConditional("voice", &testVoice);
 	ScriptInterp::addConditional("lang", &testLang);
 	ScriptInterp::addConditional("language", &testLang);
-
-	ripple = true;
 }
 
 unsigned long Runtime::getTrapMask(const char *trapname)
@@ -302,10 +293,10 @@ bool Runtime::isInput(Line *line)
 	if(line->scr.method == (Method)&Methods::scrInput)
 		return true;
 
-	if(line->scr.method == (Method)&Methods::scrCleardigits)
+	if(line->scr.method == (Method)&Methods::scrRead)
 		return true;
 
-	if(line->scr.method == (Method)&Methods::scrMenu)
+	if(line->scr.method == (Method)&Methods::scrCleardigits)
 		return true;
 
 	if(line->scr.method == (Method)&Methods::scrCollect)
@@ -322,21 +313,6 @@ bool Runtime::testDriver(ScriptInterp *interp, const char *v)
 	return false;
 }
 
-bool Runtime::testNumber(ScriptInterp *interp, const char *v)
-{
-	if(!v || !*v)
-		return false;
-
-	while(*v)
-	{
-		if(!isdigit(*v) && !ispunct(*v))
-			return false;
-		++v;
-	}
-
-	return true;
-}
-
 bool Runtime::testFile(ScriptInterp *interp, const char *v)
 {
 	BayonneSession *s = (BayonneSession *)(interp);
@@ -810,6 +786,7 @@ void Runtime::process(void)
 	remove(buf);
 	mkfifo(buf, 0770);
 	fifo = ::open(buf, O_RDWR);
+	keypaths.setValue("runfifo", buf);
 	for(;;)
 	{
 		readline(buf, sizeof(buf));
@@ -839,6 +816,79 @@ void Runtime::process(void)
 
 #endif
 
+bool Runtime::loadBinder(const char *path)
+{
+        char pathbuf[256];
+        const char *cp, *kv;
+        const char *prefix = NULL;
+        DSO *dso;  
+
+#ifdef  WIN32
+#ifdef  HAVE_TESTING
+        if(!prefix && Bayonne::provision_test)
+#ifdef  NDEBUG
+                prefix = "DEBUG";
+#else    
+                prefix = "RELEASE";
+#endif
+#endif   
+        if(!prefix)
+	 	prefix = "C:\\Program Files\\Common Files\\GNU Telephony\\Bayonne Binder";
+#else
+
+#ifdef  HAVE_TESTING
+        char prefixbuf[256];
+
+        if(!prefix && Bayonne::provision_test && !strchr(path, '/'))
+        {
+                snprintf(prefixbuf, sizeof(prefixbuf),
+                        "%s/binders/%s/.libs", SOURCE_FILES, path);
+                if(!isDir(prefixbuf))
+                        snprintf(prefixbuf, sizeof(prefixbuf),
+                                "%s/binders/%s", SOURCE_FILES, path);
+                prefix = prefixbuf;
+        }
+#endif
+        if(!prefix)
+                prefix = LIBDIR_FILES;
+#endif 
+
+#ifdef  WIN32
+        snprintf(pathbuf, sizeof(pathbuf), "%s/%s." RLL_SUFFIX, prefix, path);
+#else
+        snprintf(pathbuf, sizeof(pathbuf), "%s/%s.bin", prefix, path);
+#endif  
+
+        cp = path;
+        path = pathbuf;
+
+        kv = getLast(path); 
+
+        if(kv)
+        {
+                if(!stricmp(kv, "loaded"))
+                        return true;
+                return false;
+        }
+
+        if(!canAccess(path))
+        {
+                Bayonne::errlog("access", "cannot load %s", path);
+                return false;
+        }  
+
+        dso = new DSO(path);
+        if(!dso->isValid())
+        {
+                kv = dso->getError();
+                setValue(path, kv);
+                Bayonne::errlog("error", "cannot initialize %s", path);
+                return false;
+        }
+        setValue(path, "loaded");
+	ripple = Bayonne::provision_ripple;
+        return true;
+}                     
 		
 Runtime runtime;
 
