@@ -52,6 +52,8 @@ static int mainpid;
 
 static RETSIGTYPE stop(int signo)
 {
+	const char *cp;
+
 	if(signo > 0 && getpid() != mainpid)
 	{
 		kill(mainpid, signo);
@@ -63,6 +65,10 @@ static RETSIGTYPE stop(int signo)
         signal(SIGTERM, SIG_IGN);
         signal(SIGQUIT, SIG_IGN);
 
+	cp = keypaths.getLast("runfifo");
+	if(cp)
+		remove(cp);
+
 	BayonneService::stop();
 	BayonneDriver::stop();
 	ScriptBinder::shutdown();
@@ -101,7 +107,6 @@ static void loading(void)
 	char *plist[65];
 	const char *cp, *proto;
 	char *sp, *tok;
-	unsigned pcount = keyswitch.getIndex(plist, sizeof(plist) / sizeof(char **));
 	unsigned count = keyoptions.getCount("modules");
 	BayonneDriver *driver;
 	BayonneTranslator *translator = NULL;
@@ -185,93 +190,17 @@ static void loading(void)
 		}
         } 
 
-	
-	cp = keyoptions.getLast("driver");
+
+	driver = NULL;	
+	cp = keyengine.getLast("driver");
 	if(cp && *cp)
-	{
 		driver = BayonneDriver::loadDriver(cp);
 
-		if(!driver)
-			stop(-1);
-	}
-	else
+	if(!driver)
 	{
-		proto = keyswitch.getLast("protocol");
-		if(proto && !strnicmp(proto, "no", 2))
-		{
-			pflag = false;
-			proto = NULL;
-		}
-
-		if(proto && !stricmp(proto, "yes"))
-			proto = NULL;
-
-                if(proto && !stricmp(proto, "use"))
-                        proto = NULL; 
-
-                if(proto && !stricmp(proto, "any"))
-                        proto = NULL; 
-
-                if(proto && !stricmp(proto, "all"))
-                        proto = NULL; 
-
-		if(proto && !*proto)
-			proto = NULL;
-
-		cp = keyswitch.getLast("trunking");
-		if(cp && *cp && strnicmp(cp, "no", 2))
-			BayonneDriver::loadTrunking(cp);
-		keys = plist;
-		if(pflag)
-			pflag = BayonneDriver::useProtocols();
-
-		while(*keys && BayonneDriver::useProtocols())
-		{
-			cp = keyswitch.getLast(*keys);
-			if(!cp)
-				cp = "";
-			pcount = atoi(cp);
-			cp = *keys;
-			if(proto && !stricmp(cp, proto))
-				pcount = 0;
-			else if(!stricmp(cp, "timeslots"))
-				pcount = 0;
-			else if(!stricmp(cp, "framing"))
-				pcount = 0;
-			else if(!stricmp(cp, "trunking"))
-				pcount = 0;
-			else if(!stricmp(cp, "protocol"))
-				pcount = 0;
-			else if(!stricmp(cp, "encoding"))
-				pcount = 0;
-			++keys;
-			if(!pcount)
-				continue;
-			BayonneDriver::loadProtocol(cp, pcount);
-		}
-		if(proto)
-			BayonneDriver::loadProtocol(proto, 0);
-	}	
-
-#ifdef	HAVE_CAPAUDIO
-	sp = (char *)keyserver.getLast("audio");
-        if(sp && !strnicmp(sp, "no", 2))
-                sp = NULL;
-
-        if(sp && !*sp)
-                sp = NULL;
-
-        if(sp)
-                cp = strtok_r(sp, " ,;:\t", &tok);
-        else
-                cp = NULL;
-
-        while(cp)
-        {
-                Bayonne::loadAudio(cp);
-                cp = strtok_r(NULL, " ,;:\t", &tok);
-        }
-#endif
+		slog.critical("no driver loaded; enable in server.conf...");
+		stop(-1);
+	}
 
 	sp = (char *)keyserver.getLast("monitoring");
 	if(sp && !strnicmp(sp, "no", 2))
@@ -317,7 +246,7 @@ start:
 	BayonneSysexec::startup();
 #endif
 // reload
-	loadBinder(keyserver.getLast("binding"));
+	runtime.loadBinder(keyserver.getLast("binding"));
 	Bayonne::reload();
 	if(!Bayonne::compile_count)
 	{
@@ -361,6 +290,7 @@ static void checking(void)
 	logging();
 	if(!Bayonne::getTimeslotCount())
 		Bayonne::allocate(1, dynamic_cast<ScriptCommand *>(&runtime));
+	runtime.loadBinder(keyserver.getLast("binding"));
 	Bayonne::reload();
         if(!Bayonne::compile_count)
         {
@@ -472,7 +402,6 @@ int main(int argc, char **argv)
                 	if(keypaths.getLast("addons"))
                     		runtime.setValue("addons", keypaths.getLast("addons"));    
                 	runtime.setValue("include", keypaths.getLast("macros")); 
-			loadBinder(keyserver.getLast("binding"));
 			checking();
 		}
 #ifdef	HAVE_TESTING
@@ -532,35 +461,6 @@ int main(int argc, char **argv)
 	Bayonne::provision_daemon = true;
 
 	loadConfig();
-
-	if(!stricmp(argv0, "bayonne"))
-	{
-		cp = keyengine.getLast("driver");
-		if(cp && *cp)
-			keyoptions.setValue("driver", cp);
-		cp = keyengine.getLast("timeslots");
-		if(cp && atoi(cp) > 0)
-			keyswitch.setValue("timeslots", cp);
-	}
-	else
-	{
-		cp = keygateway.getLast("timeslots");
-		if(cp && *cp)
-			keyswitch.setValue("timeslots", cp);
-		
-		cp = keygateway.getLast("trunking");
-		if(cp && *cp)
-			keyswitch.setValue("trunking", cp);
-
-		cp = keygateway.getLast("binding");
-		if(cp && *cp)
-			keyserver.setValue("binding", cp);
-
-		cp = keygateway.getLast("monitoring");
-		if(cp && *cp)
-			keyserver.setValue("monitoring", cp);
-	}
-
 	parseConfig(argv);
 	liveConfig();
 	if(Bayonne::provision_check)
@@ -587,7 +487,7 @@ int main(int argc, char **argv)
         Bayonne::errlog("notice", "starting %s on %s %s; timeslots=%s",
                 VERSION,
                 keyserver.getLast("cpu"), keyserver.getLast("platform"),
-                keyswitch.getLast("timeslots"));   
+                keyengine.getLast("timeslots"));   
 
 	loading();
 
